@@ -1,4 +1,5 @@
 from starlette import status as status
+from starlette.exceptions import HTTPException
 from starlette.responses import Response
 
 from xpresso.applications import App
@@ -21,7 +22,7 @@ from xpresso.bodies import (
 )
 from xpresso.datastructures import UploadFile
 from xpresso.dependencies.models import Depends
-from xpresso.exceptions import HTTPException
+from xpresso.exception_handlers import ExcHandler
 from xpresso.parameters import (
     CookieParam,
     FromCookie,
@@ -40,6 +41,7 @@ from xpresso.routing.websockets import WebSocketRoute
 from xpresso.websockets import WebSocket
 
 __all__ = (
+    "ExcHandler",
     "Operation",
     "Path",
     "QueryParam",
